@@ -17,9 +17,17 @@ class MissionFfiLightcurveBuilder(LightcurveBuilder):
         self.star_catalog = TicStarCatalog()
 
     def build(self, object_info):
+        mission_id = object_info.mission_id()
+        sherlock_id = object_info.sherlock_id()
+        quarters = None
+        sectors = None
+        logging.info("Retrieving star catalog info...")
+        mission, mission_prefix, id = super().parse_object_id(mission_id)
         transits_min_count = 1
         star_info = None
         quarters = None
+        if mission_prefix not in self.star_catalogs:
+            raise ValueError("Wrong object id " + mission_id)
         if isinstance(object_info, MissionFfiCoordsObjectInfo):
             coords = SkyCoord(ra=object_info.ra, dec=object_info.dec, unit=(u.deg, u.deg))
             star = eleanor.multi_sectors(coords=coords, sectors=object_info.sectors)
