@@ -21,15 +21,15 @@ class MissionLightcurveBuilder(LightcurveBuilder):
         star_info = starinfo.StarInfo(sherlock_id, *self.star_catalogs[mission_prefix].catalog_info(id))
         logging.info("Downloading lightcurve files...")
         if mission == "TESS" and object_info.sectors != 'all':
-            lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, sector=object_info.sectors)\
+            lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, cadence="short", sector=object_info.sectors)\
                 .download_all()
         elif mission == "TESS":
-            lcf = lk.search_lightcurvefile(str(mission_id), mission=mission).download_all()
+            lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, cadence="short").download_all()
         elif object_info.sectors != 'all':
-            lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, quarter=object_info.sectors)\
+            lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, cadence="short", quarter=object_info.sectors)\
                 .download_all()
         else:
-            lcf = lk.search_lightcurvefile(str(mission_id), mission=mission).download_all()
+            lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, cadence="short").download_all()
         if lcf is None:
             raise ObjectProcessingError("Light curve not found for object id " + mission_id)
         lc = lcf.PDCSAP_FLUX.stitch().remove_nans()
